self.__precacheManifest = [
  {
    "revision": "229c360febb4351a89df",
    "url": "/static/js/runtime~main.229c360f.js"
  },
  {
    "revision": "940a2b129b541c00203d",
    "url": "/static/js/main.940a2b12.chunk.js"
  },
  {
    "revision": "b773eb2ead2537aafb10",
    "url": "/static/js/1.b773eb2e.chunk.js"
  },
  {
    "revision": "940a2b129b541c00203d",
    "url": "/static/css/main.6109b597.chunk.css"
  },
  {
    "revision": "b773eb2ead2537aafb10",
    "url": "/static/css/1.d6789a98.chunk.css"
  },
  {
    "revision": "8df1c53e7a1a87423916977476c58308",
    "url": "/index.html"
  }
];